============
Installation
============

At the command line::

    $ easy_install config-handle

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv config-handle
    $ pip install config-handle
